@@ -96,20 +96,18 @@ class objearth():
         return xarray.merge([blue,green,red,nir,pixel_qa])
 
     @staticmethod
-    def plotshow(DataArray,lst=True):
+    def plotshow(DataArray,cmap=True,area=True,zenmode=False,figsize=(8,8),xlabel="x axis size",ylabel="y axis size",title=''):
         '''
         Plot image 
         :param DataArray: Numpy array/Xarray data array
         '''
-        DataArray = DataArray
-        lst = lst
         if type(DataArray) == xarray.core.dataarray.DataArray:
-            if lst==True:
+            if area==True:
                 ymax = 0 ; ymin = DataArray.shape[0]
                 xmin = 0 ; xmax = DataArray.shape[1] 
             else:
-                ymax = lst[0] ; ymin = lst[1]
-                xmin = lst[2] ; xmax = lst[3]
+                ymax = area[0] ; ymin = area[1]
+                xmin = area[2] ; xmax = area[3]
             lon  =  DataArray.longitude.to_numpy()[xmin:xmax]
             lon0 =  lon[0] ; lon1 =  lon[-1]
             lat  =  DataArray.latitude.to_numpy()[ymax:ymin]
@@ -121,9 +119,9 @@ class objearth():
             def axis(x=0):
                 return x
             fig,ax = plt.subplots(constrained_layout=True)
-            fig.set_size_inches(7,7)
-            ax.set_xlabel('x axis size')
-            ax.set_ylabel('y axis size')
+            fig.set_size_inches(8,8)
+            ax.set_xlabel(xlabel)
+            ax.set_ylabel(ylabel)
             ax.imshow(DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
             secax_x = ax.secondary_xaxis('top',functions=(longitude,axis))
             secax_x.set_xlabel('longitude')
@@ -133,21 +131,46 @@ class objearth():
             secax_y.set_ylabel('latitute')
             plt.grid(color='w', linestyle='-', linewidth=0.15)
             plt.show()
+
         elif type(DataArray) == numpy.ndarray:
-            if lst==True:
+        #Area
+            if area==True:
                 ymax = 0 ; ymin = DataArray.shape[0]
                 xmin = 0 ; xmax = DataArray.shape[1]
             else:
-                ymax = lst[0] ; ymin = lst[1]
-                xmin = lst[2] ; xmax = lst[3]
-            plt.figure(figsize=(8,8))
-            plt.imshow(DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
-            plt.xlabel("x axis size")
-            plt.ylabel("y axis size")
-            plt.grid(color='w', linestyle='-', linewidth=0.15)
+                ymax = area[0] ; ymin = area[1]
+                xmin = area[2] ; xmax = area[3]
+            real_margin_img = DataArray[ymax:ymin,xmin:xmax]
+            #plotshow
+            plt.figure(figsize=(figsize))
+            color_map = plt.imshow(real_margin_img,extent=[xmin,xmax,ymin,ymax])
+            if zenmode == False:
+                plt.imshow(DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
+                plt.title(title)
+                plt.xlabel(xlabel)
+                plt.ylabel(ylabel)
+                plt.grid(color='w', linestyle='-', linewidth=0.15)
+            else:
+                plt.axis('off')
+
+            # faction
+            im_ratio = real_margin_img.shape[1]/real_margin_img.shape[0]
+            fac = ratio(im_ratio)
+            #print(real_margin_img.shape[1],real_margin_img.shape[0],im_ratio,fac)
+            
+            #colorbar
+            min = real_margin_img.min()
+            max = real_margin_img.max()
+            plt.clim(min,max)
+            if cmap==True:
+                color_map.set_cmap('viridis')
+            else:
+                color_map.set_cmap(cmap)
+            plt.colorbar(orientation="vertical",fraction=fac)
             plt.show()
         else:
-            print("Nonetype :",type(DataArray))
+                print("Nonetype :",type(DataArray))
+            
 
     def percentcloud(self,Dataset):
         '''
@@ -586,6 +609,14 @@ class objearth():
         nc5 = colors.LinearSegmentedColormap('new_cmap',segmentdata=cdict)
         return nc5
 
+    # def stamp(param=''):
+    #     import datetime,platform
+    #     print(datetime.datetime.now().strftime('"""\n%c'))
+    #     print('name:',param)
+    #     print('OS system: ',platform.system())
+    #     print('@author: Tun.k\n"""')
+    # # stamp()
+
 
 
 from sklearn.preprocessing import MinMaxScaler, RobustScaler
